==> haskell-regex-applicative-0.3.4-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-applicative
version:              0.3.4
visibility:           public
id:                   regex-applicative-0.3.4-2CJvahtSR99BmTg0A3oHdr
key:                  regex-applicative-0.3.4-2CJvahtSR99BmTg0A3oHdr
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/feuerbach/regex-applicative
synopsis:             Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.

category:             Text
abi:                  407fa89f6717f756d8f3b5e63617d113
exposed:              True
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Common
    Text.Regex.Applicative.Object Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue

hidden-modules:
    Text.Regex.Applicative.Interface Text.Regex.Applicative.Types
    Text.Regex.Applicative.Compile

import-dirs:          /usr/lib/ghc-8.10.3/site-local/regex-applicative-0.3.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/regex-applicative-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/regex-applicative-0.3.4
hs-libraries:         HSregex-applicative-0.3.4-2CJvahtSR99BmTg0A3oHdr
depends:
    base-4.14.1.0 containers-0.6.2.1
    filtrable-0.1.6.0-DQfc83femVpKgtdPSKUvhl transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-applicative-0.3.4-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-applicative
version:              0.3.4
visibility:           public
id:                   regex-applicative-0.3.4-4juVt6VWBjFCSqT6ufeD6H
key:                  regex-applicative-0.3.4-4juVt6VWBjFCSqT6ufeD6H
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/feuerbach/regex-applicative
synopsis:             Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.

category:             Text
abi:                  42a2630a4b11c38cb46c0a43c9ddbfcc
exposed:              True
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Common
    Text.Regex.Applicative.Object Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue

hidden-modules:
    Text.Regex.Applicative.Interface Text.Regex.Applicative.Types
    Text.Regex.Applicative.Compile

import-dirs:          /usr/lib/ghc-8.10.3/site-local/regex-applicative-0.3.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/regex-applicative-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/regex-applicative-0.3.4
hs-libraries:         HSregex-applicative-0.3.4-4juVt6VWBjFCSqT6ufeD6H
depends:
    base-4.14.1.0 containers-0.6.2.1
    filtrable-0.1.6.0-A37nwULuE5HJh4eZixRdIX transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
